@@ -12,7 +12,7 @@ function install_crd {
 
 # Can't rely on associative arrays for old Bash versions (e.g. OSX)
 install_crd \
-  "vendor/github.com/openshift/api/operator/v1/0000_50_ingress-operator_00-custom-resource-definition.yaml" \
+  "vendor/github.com/openshift/api/operator/v1/0000_50_ingress-operator_00-ingresscontroller.crd.yaml" \
   "manifests/00-custom-resource-definition.yaml"
 
 install_crd \
