@@ -8,7 +8,10 @@ import (
 	operatorv1 "github.com/openshift/api/operator/v1"
 	iov1 "github.com/openshift/api/operatoringress/v1"
 	"github.com/openshift/cluster-ingress-operator/pkg/dns"
+	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
+	"k8s.io/apimachinery/pkg/runtime"
+	"sigs.k8s.io/controller-runtime/pkg/client/fake"
 )
 
 func TestPublishRecordToZones(t *testing.T) {
@@ -569,3 +572,59 @@ func TestRecordIsAlreadyPublishedToZone(t *testing.T) {
 		}
 	}
 }
+
+func TestCustomCABundle(t *testing.T) {
+	cases := []struct {
+		name             string
+		cm               *corev1.ConfigMap
+		expectedCABundle string
+	}{
+		{
+			name: "no configmap",
+		},
+		{
+			name: "no CA bundle in configmap",
+			cm: &corev1.ConfigMap{
+				ObjectMeta: metav1.ObjectMeta{
+					Namespace: "openshift-config-managed",
+					Name:      "kube-cloud-config",
+				},
+				Data: map[string]string{
+					"other-key": "other-data",
+				},
+			},
+		},
+		{
+			name: "custom CA bundle",
+			cm: &corev1.ConfigMap{
+				ObjectMeta: metav1.ObjectMeta{
+					Namespace: "openshift-config-managed",
+					Name:      "kube-cloud-config",
+				},
+				Data: map[string]string{
+					"ca-bundle.pem": "a custom bundle",
+				},
+			},
+			expectedCABundle: "a custom bundle",
+		},
+	}
+	for _, tc := range cases {
+		t.Run(tc.name, func(t *testing.T) {
+			scheme := runtime.NewScheme()
+			corev1.AddToScheme(scheme)
+			resources := []runtime.Object{}
+			if tc.cm != nil {
+				resources = append(resources, tc.cm)
+			}
+			client := fake.NewFakeClientWithScheme(scheme, resources...)
+			r := reconciler{client: client}
+			actualCABundle, err := r.customCABundle()
+			if err != nil {
+				t.Fatalf("unexpected error from customCABundle: %v", err)
+			}
+			if a, e := actualCABundle, tc.expectedCABundle; a != e {
+				t.Errorf("unexpected CA bundle: expected=%s; got %s", e, a)
+			}
+		})
+	}
+}
